@@ -4,6 +4,7 @@ pub use notation_proto;
 
 pub mod bar;
 pub mod bar_lane;
+pub mod form;
 pub mod lane_entry;
 pub mod lane_kind;
 pub mod model_entry;
@@ -12,6 +13,7 @@ pub mod play;
 pub mod section;
 pub mod tab;
 pub mod tab_bar;
+pub mod tab_chord;
 pub mod track;
 pub mod util;
 
@@ -21,6 +23,8 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::bar_lane::{BarLane, BarLaneProps};
     #[doc(hidden)]
+    pub use crate::form::{Form};
+    #[doc(hidden)]
     pub use crate::lane_entry::{LaneEntry, LaneEntryProps};
     #[doc(hidden)]
     pub use crate::lane_kind::LaneKind;
@@ -35,12 +39,14 @@ pub mod prelude {
     #[doc(hidden)]
     pub use crate::play::play_state::{PlayState, PlayingState};
     #[doc(hidden)]
-    pub use crate::section::{Form, Section};
+    pub use crate::section::{Section};
     #[doc(hidden)]
     pub use crate::tab::Tab;
     #[doc(hidden)]
     pub use crate::tab_bar::{TabBar, TabBarProps};
     #[doc(hidden)]
+    pub use crate::tab_chord::{TabChord};
+    #[doc(hidden)]
     pub use crate::track::{Track, TrackProps};
     #[doc(hidden)]
     pub use notation_proto::prelude::Tab as ProtoTab;
